use chrono::{NaiveDate, NaiveTime};
use rinja::Template;

use crate::filters;
use crate::models::{Availability, Role, User};

pub mod delete;
pub mod get_new;
pub mod get_overview;
pub mod get_update;
pub mod post_new;
pub mod post_update;

#[derive(Template)]
#[template(path = "availability/new_or_edit.html")]
struct NewOrEditAvailabilityTemplate<'a> {
    user: User,
    date: NaiveDate,
    whole_day: bool,
    id: Option<i32>,
    start_time: Option<&'a str>,
    end_time: Option<&'a str>,
    comment: Option<&'a str>,
    slot_suggestions: Vec<(NaiveTime, NaiveTime)>,
}

fn calc_free_slots_cor(availabilities: &Vec<&Availability>) -> Vec<(NaiveTime, NaiveTime)> {
    let mut times = Vec::new();

    for a in availabilities {
        let Some(start_time) = a.start_time else {
            continue;
        };

        let Some(end_time) = a.end_time else {
            continue;
        };

        times.push((start_time, end_time));
    }

    if times.len() == 0 {
        return Vec::new();
    }
    println!("zeiten {times:?}");

    times.sort();

    println!("zeiten sort {times:?}");

    let mut changed = true;
    while changed {
        changed = false;

        for i in 0..(times.len() - 1) {
            let b = times[i + 1].clone();
            let a = times.get_mut(i).unwrap();

            if a.1 == b.0 {
                a.1 = b.1;
                times.remove(i + 1);
                changed = true;
                break;
            }
        }
    }

    let start = NaiveTime::parse_from_str("00:00", "%R").unwrap();
    let end = NaiveTime::parse_from_str("23:59", "%R").unwrap();
    println!("zeiten unified {times:?}");

    // now times contains unified list of existing availabilities -> now calculate the "inverse"

    let mut available_slots = Vec::new();
    if times.first().unwrap().0 != start {
        available_slots.push((start, times.first().unwrap().0));
    }

    let mut iterator = times.iter().peekable();
    while let Some(a) = iterator.next() {
        if let Some(b) = iterator.peek() {
            available_slots.push((a.1, b.0));
        }
    }

    if times.last().unwrap().1 != end {
        available_slots.push((times.last().unwrap().1, end));
    }

    println!("available {available_slots:?}");
    available_slots
}
